from setuptools import setup

setup(
    name='currenpy',
    version='1.0',
    packages=['currenpy'],
    url='https://github.com/theunravelghoul/currenpy',
    license='MIT',
    author='theunravelghoul',
    author_email='',
    description='Python currency management library.'
)
